function BicycleCounts2015 = importfilett(filename, dataLines)
%IMPORTFILE1 Import data from a text file
%  BICYCLECOUNTS2015 = IMPORTFILE1(FILENAME) reads data from text file
%  FILENAME for the default selection.  Returns the data as a table.
%
%  BICYCLECOUNTS2015 = IMPORTFILE1(FILE, DATALINES) reads data for the
%  specified row interval(s) of text file FILENAME. Specify DATALINES as
%  a positive scalar integer or a N-by-2 array of positive scalar
%  integers for dis-contiguous row intervals.
%
%  Example:
%  BicycleCounts2015 = importfile1("C:\Users\ldempsey\OneDrive - MathWorks\EXPO\2019\Data\BicycleCounts2015.csv", [2, Inf]);
%
%  See also READTABLE.
%
% Auto-generated by MATLAB on 17-Sep-2019 13:30:11

%% Input handling

% If dataLines is not specified, define defaults
if nargin < 2
    dataLines = [2, Inf];
end

%% Setup the Import Options and import the data
opts = delimitedTextImportOptions("NumVariables", 6);

% Specify range and delimiter
opts.DataLines = dataLines;
opts.Delimiter = ",";

% Specify column names and types
opts.VariableNames = ["Date", "Time", "Day", "Westbound", "Eastbound", "Total"];
opts.VariableTypes = ["datetime", "datetime", "categorical", "double", "double", "double"];

% Specify file level properties
opts.ExtraColumnsRule = "ignore";
opts.EmptyLineRule = "read";

% Specify variable properties
opts = setvaropts(opts, "Day", "EmptyFieldRule", "auto");
opts = setvaropts(opts, "Date", "InputFormat", "MM/dd/yyyy");
opts = setvaropts(opts, "Time", "InputFormat", "HH:mm:ss");

% Import the data
BicycleCounts2015 = readtable(filename, opts);

% Convert to timetable
BicycleCounts2015 = table2timetable( BicycleCounts2015(:,3:end), 'RowTimes', BicycleCounts2015.Date + timeofday(BicycleCounts2015.Time) );
BicycleCounts2015.Time.Format = 'MM/dd/yyyy HH:mm:ss';
BicycleCounts2015 = sortrows(BicycleCounts2015);
end